[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# Paper-Implementation-Template
A simple implementation of LeNet5 for practice for the book "Pytorch Pocket Reference"

LeNet is abunch of convolution and linear layers with max pools.

Paper Link

# Appreciation
* Lucidrains
* Agorians



# Install

# Usage

# Architecture

# Todo


# License

# Citations

